@@ -6,6 +6,7 @@ from pandas.core.dtypes.common import (
 )
 import pandas as pd
 import google.protobuf.wrappers_pb2 as proto
+from google.protobuf.json_format import MessageToJson
 import numpy as np
 import google
 import math
@@ -175,6 +176,9 @@ def __dataTypeToString(dataType):
         return "String"
     raise Exception(f'Unsupprted dataType: {dataType}')
 
+def __tsToUnixEpochSeconds(timeStamp):
+    return np.int_(timeStamp.value / 10**9)
+
 # Iterate a dataframe's rows as api.DataRecordsReply
 # time columns must be serialized as numbers prior to this
 def __serializeDataFrame(df, project_cols, chunk_size = 100):
@@ -212,12 +216,13 @@ def __serializeDataFrame(df, project_cols, chunk_size = 100):
                     if row[c] == None or math.isnan(row[c].value):
                         times[time_dict[c]] = api.OptionalTime(value=None)
                     else:
-                        times[time_dict[c]] = api.OptionalTime(value=proto.Int64Value(value=row[c].value))
+                        times[time_dict[c]] = api.OptionalTime(value=proto.Int64Value(value=__tsToUnixEpochSeconds(row[c])))
             data_records.append(api.DataRecord(strings=strings, numbers=numbers, times=times))
         yield api.DataRecordsReply(records=data_records)
 
 
 def dataSourceUniquesStreamPandas(df, request, chunk_size = 100):
+    print("dataSourceUniquesStreamPandas", MessageToJson(request))
     columns = list(request.columns)
     unique_df = df[columns].drop_duplicates()
     # Run the serialize code
@@ -225,6 +230,7 @@ def dataSourceUniquesStreamPandas(df, request, chunk_size = 100):
 
 
 def dataSourceQueryStreamPandas(df, request):
+    print("dataSourceQueryStreamPandas", MessageToJson(request))
     # Make and resolve the data for each line requested.
     # We yield batches of DataRecordsReply, one for each line requested
     project_cols = list(map(lambda c:  c.name, request.projectColumns))
@@ -271,7 +277,7 @@ def dataSourceQueryStreamPandas(df, request):
                         times[time_dict[c]] = api.OptionalTime(value=None)
                     else:
                         # read time as .value
-                        times[time_dict[c]] = api.OptionalTime(value=proto.Int64Value(value=row[c].value))
+                        times[time_dict[c]] = api.OptionalTime(value=proto.Int64Value(value=__tsToUnixEpochSeconds(row[c])))
 
             data_records.append(api.DataRecord(strings=strings, numbers=numbers, times=times))
         yield api.DataRecordsReply(records=data_records)
